# estimation.fegaussian_.Fegaussian

    estimation.fegaussian_.Fegaussian(
        self,
        FixestFormula,
        data,
        ssc_dict,
        drop_singletons,
        drop_intercept,
        weights,
        weights_type,
        collin_tol,
        fixef_tol,
        lookup_demeaned_data,
        tol,
        maxiter,
        solver,
        store_data=True,
        copy_data=True,
        lean=False,
        sample_split_var=None,
        sample_split_value=None,
        separation_check=None,
        context=0,
    )

Class for the estimation of a fixed-effects GLM with normal errors.